# yaqd-core-python

[![PyPI version](https://badge.fury.io/py/yaqd-core.svg)](https://badge.fury.io/py/yaqd-core)
[![Anaconda-Server Badge](https://anaconda.org/conda-forge/yaqd-core/badges/version.svg)](https://anaconda.org/conda-forge/yaqd-core)

Core python package for implementing yaq daemons, and associated utilities.

Documentation at https://yaqd-core-python.yaq.fyi

When installed, this package exposes the following "abstract" daemons.
These are useful for testing purposes.
- [yaqd-hardware](https://yaq.fyi/daemons/hardware/)
- [yaqd-continuous-hardware](https://yaq.fyi/daemons/continuous-hardware/)
